@@ -13,17 +13,117 @@
 #include <vector>
 #include <algorithm>
 
+#include <iostream>
+
 #include "Fish.h"
 #include "random_functions.h"
 #include "helper_functions.h"
 
+#include <RcppParallel.h>
+
 #include <RcppArmadillo.h>
 // [[Rcpp::depends("RcppArmadillo")]]
 using namespace Rcpp;
 
+void update_pop(const std::vector<Fish>& Pop,
+                std::vector<Fish>& new_generation,
+                size_t pop_size,
+                double morgan,
+                const std::vector<double>& fitness,
+                const double& maxFitness,
+                bool use_selection,
+                double multiplicative_selection,
+                int num_threads) {
+
+  if (Pop.size() != pop_size) {
+    stop("wrong size pop");
+  }
+  if (new_generation.size() != pop_size) {
+    stop("new_generation wrong size");
+  }
+
+
+  int num_seeds = num_threads * 2; // tbb might re-start threads due to the load-balancer
+  if (num_threads == -1) {
+    num_seeds = 20;
+  }
+  std::vector< int > seed_values(num_seeds);
+
+  {
+    rnd_t rndgen;
+    for (int i = 0; i < num_seeds; ++i) {
+      seed_values[i] = rndgen.random_number(INT_MAX); // large value
+    }
+  }
+
+  if (num_threads == 1) {
+    rnd_t rndgen2;
+    for (unsigned i = 0; i < pop_size; ++i) {
+      int index1 = 0;
+      int index2 = 0;
+      if (use_selection) {
+        index1 = draw_prop_fitness(fitness, maxFitness, rndgen2);
+        index2 = draw_prop_fitness(fitness, maxFitness, rndgen2);
+        while(index2 == index1) index2 = draw_prop_fitness(fitness, maxFitness, rndgen2);
+      } else {
+        index1 = rndgen2.random_number( pop_size );
+        index2 = rndgen2.random_number( pop_size );
+        while(index2 == index1) index2 = rndgen2.random_number( pop_size );
+      }
+
+      new_generation[i] = mate(Pop[index1],
+                               Pop[index2],
+                                  morgan, rndgen2);
+    }
+  } else {
+
+
+    int seed_index = 0;
+    std::mutex mutex;
+
+      tbb::task_scheduler_init _tbb((num_threads > 0) ? num_threads : tbb::task_scheduler_init::automatic);
+
+      tbb::parallel_for(
+        tbb::blocked_range<unsigned>(0, pop_size),
+        [&](const tbb::blocked_range<unsigned>& r) {
+
+          rnd_t rndgen2(seed_values[seed_index]);
+          {
+            std::lock_guard<std::mutex> _(mutex);
+            seed_index++;
+            if (seed_index > num_seeds) { // just in case.
+              for (int i = 0; i < num_seeds; ++i) {
+                seed_values[i] = rndgen2.random_number(INT_MAX);
+              }
+              seed_index = 0;
+            }
+          }
+
+          for (unsigned i = r.begin(); i < r.end(); ++i) {
+            int index1 = 0;
+            int index2 = 0;
+            if (use_selection) {
+              index1 = draw_prop_fitness(fitness, maxFitness, rndgen2);
+              index2 = draw_prop_fitness(fitness, maxFitness, rndgen2);
+              while(index2 == index1) index2 = draw_prop_fitness(fitness, maxFitness, rndgen2);
+            } else {
+              index1 = rndgen2.random_number( pop_size );
+              index2 = rndgen2.random_number( pop_size );
+              while(index2 == index1) index2 = rndgen2.random_number( pop_size );
+            }
+
+            new_generation[i] = mate(Pop[index1],
+                                     Pop[index2],
+                                        morgan, rndgen2);
+          }
+      });
+  }
+  return;
+}
+
 std::vector< Fish > simulate_Population(const std::vector< Fish>& sourcePop,
                                         const NumericMatrix& select,
-                                        int pop_size,
+                                        size_t pop_size,
                                         int total_runtime,
                                         double morgan,
                                         bool verbose,
@@ -34,7 +134,9 @@ std::vector< Fish > simulate_Population(const std::vector< Fish>& sourcePop,
                                         std::vector<double>& junctions,
                                         bool multiplicative_selection,
                                         int num_alleles,
-                                        const std::vector<int>& founder_labels) {
+                                        const std::vector<int>& founder_labels,
+                                        rnd_t& rndgen,
+                                        int num_threads) {
 
   bool use_selection = false;
   if(select(1, 1) >= 0) use_selection = true;
@@ -56,6 +158,7 @@ std::vector< Fish > simulate_Population(const std::vector< Fish>& sourcePop,
   if(updateFreq < 1) updateFreq = 1;
 
   if(verbose) {
+  //  Rcout << "running until: " << total_runtime << "\n";
     Rcout << "0--------25--------50--------75--------100\n";
     Rcout << "*";
   }
@@ -86,46 +189,33 @@ std::vector< Fish > simulate_Population(const std::vector< Fish>& sourcePop,
       }
     }
 
-    std::vector<Fish> newGeneration(pop_size);
-    std::vector<double> newFitness;
-    double newMaxFitness = -1.0;
-    for (int i = 0; i < pop_size; ++i)  {
-      int index1 = 0;
-      int index2 = 0;
-      if (use_selection) {
-        index1 = draw_prop_fitness(fitness, maxFitness);
-        index2 = draw_prop_fitness(fitness, maxFitness);
-        while(index2 == index1) index2 = draw_prop_fitness(fitness, maxFitness);
-      } else {
-        index1 = random_number( (int)Pop.size() );
-        index2 = random_number( (int)Pop.size() );
-        while(index2 == index1) index2 = random_number( (int)Pop.size() );
-      }
+    std::vector<Fish> new_generation(pop_size);
 
-      newGeneration[i] = mate(Pop[index1], Pop[index2], morgan);
+  //  std::cerr << "t " << t << std::flush;
+    update_pop(Pop, new_generation, pop_size,
+               morgan, fitness, maxFitness,  use_selection,
+               multiplicative_selection, num_threads);
 
-      double fit = -2.0;
-      if(use_selection) fit = calculate_fitness(newGeneration[i], select, multiplicative_selection);
-      if(fit > newMaxFitness) newMaxFitness = fit;
-
-      newFitness.push_back(fit);
-    }
+  //  std::cerr << " updated\n" << std::flush;
 
     if (t % updateFreq == 0 && verbose) {
       Rcout << "**";
     }
 
-    if (t > 2 && is_fixed(Pop) && verbose) {
-      Rcout << "\n After " << t << " generations, the population has become completely homozygous and fixed\n";
+    if (t > 2 && is_fixed(Pop)) {
+      if (verbose) Rcout << "\n After " << t << " generations, the population has become completely homozygous and fixed\n";
       R_FlushConsole();
       return(Pop);
     }
 
     Rcpp::checkUserInterrupt();
-
-    Pop.swap(newGeneration);
-    fitness.swap(newFitness);
-    maxFitness = newMaxFitness;
+    Pop.swap(new_generation);
+    if (use_selection) {
+      for (size_t i = 0; i < pop_size; ++i) {
+        fitness[i] = calculate_fitness(Pop[i], select, multiplicative_selection);
+      }
+      maxFitness = *std::max_element(fitness.begin(), fitness.end());
+    }
   }
   if(verbose) Rcout << "\n";
   return(Pop);
@@ -144,10 +234,9 @@ List simulate_cpp(Rcpp::NumericVector input_population,
                   NumericVector track_markers,
                   bool track_junctions,
                   bool multiplicative_selection,
-                  int seed) {
-
-  set_seed(seed);
-  set_poisson(morgan);
+                  int num_threads) {
+try {
+  rnd_t rndgen;
 
   std::vector< Fish > Pop;
   int number_of_alleles = number_of_founders;
@@ -156,6 +245,7 @@ List simulate_cpp(Rcpp::NumericVector input_population,
   track_markers = scale_markers(track_markers, morgan);
 
   if (input_population[0] > -1e4) {
+  //  Rcout << "found input population, converting\n"; force_output();
 
     Pop = convert_NumericVector_to_fishVector(input_population);
 
@@ -170,20 +260,20 @@ List simulate_cpp(Rcpp::NumericVector input_population,
       // the new population has to be seeded from the input!
       std::vector< Fish > Pop_new;
       for (size_t j = 0; j < pop_size; ++j) {
-        int index = random_number(Pop.size());
+        int index = rndgen.random_number(Pop.size());
         Pop_new.push_back(Pop[index]);
       }
       Pop = Pop_new;
     }
   } else {
     for (size_t i = 0; i < pop_size; ++i) {
-      int founder_1 = draw_random_founder(starting_proportions);
-      int founder_2 = draw_random_founder(starting_proportions);
+      int founder_1 = draw_random_founder(starting_proportions, rndgen);
+      int founder_2 = draw_random_founder(starting_proportions, rndgen);
 
       Fish p1 = Fish( founder_1 );
       Fish p2 = Fish( founder_2 );
 
-      Pop.push_back(mate(p1,p2, morgan));
+      Pop.push_back(mate(p1,p2, morgan, rndgen));
     }
     for (int i = 0; i < number_of_alleles; ++i) {
       founder_labels.push_back(i);
@@ -218,8 +308,13 @@ List simulate_cpp(Rcpp::NumericVector input_population,
                                                     junctions,
                                                     multiplicative_selection,
                                                     number_of_alleles,
-                                                    founder_labels);
+                                                    founder_labels,
+                                                    rndgen,
+                                                    num_threads);
 
+ // if (verbose) {
+//    Rcout << "done simulating\n";
+//  }
   arma::mat final_frequencies = update_all_frequencies_tibble(outputPop,
                                                               track_markers,
                                                               founder_labels,
@@ -231,4 +326,10 @@ List simulate_cpp(Rcpp::NumericVector input_population,
                        Named("initial_frequencies") = initial_frequencies,
                        Named("final_frequencies") = final_frequencies,
                        Named("junctions") = junctions);
+} catch(std::exception &ex) {
+  forward_exception_to_r(ex);
+} catch(...) {
+  ::Rf_error("c++ exception (unknown reason)");
+}
+return NA_REAL;
 }
