@@ -7,25 +7,27 @@ test_that("select population two_alleles", {
   s <- 0.1
   select_matrix[1, ] <- c(0.05, 1.0, 1 + 0.5 * s, 1 + s, 0)
 
-  selected_pop <- simulate_admixture(pop_size = 100,
-                                     number_of_founders = 10,
+  selected_pop <- simulate_admixture(module = ancestry_module(number_of_founders =
+                                                                10,
+                                                              morgan = 1),
+                                     pop_size = 100,
                                      total_runtime = 100,
-                                     morgan = 1,
                                      select_matrix = select_matrix)
 
   testthat::expect_equal(length(selected_pop$population), 100)
   testthat::expect_true(verify_population(selected_pop$population))
 
-  calculate_marker_frequency(selected_pop$population, 0.5)
+  vv <- calculate_marker_frequency(selected_pop$population, 0.05)
 
 
   number_of_founders <- 10
   run_time <- 100
 
-  selected_pop <- simulate_admixture(pop_size = 100,
-                                     number_of_founders = number_of_founders,
+  selected_pop <- simulate_admixture(module = ancestry_module(number_of_founders =
+                                                                number_of_founders,
+                                                              morgan = 1),
+                                     pop_size = 100,
                                      total_runtime = run_time,
-                                     morgan = 1,
                                      select_matrix = select_matrix)
 
   testthat::expect_equal(length(selected_pop$population), 100)
@@ -35,10 +37,11 @@ test_that("select population two_alleles", {
 test_that("select on population", {
   testthat::skip_on_os("solaris")
   message("test selection on population")
-  sourcepop <- simulate_admixture(pop_size = 100,
-                                 number_of_founders = 10,
-                                 total_runtime = 1000,
-                                 morgan = 1)
+  sourcepop <- simulate_admixture(module = ancestry_module(number_of_founders =
+                                                             10,
+                                                           morgan = 1),
+                                  pop_size = 100,
+                                 total_runtime = 1000)
 
   testthat::expect_true(verify_population(sourcepop))
 
@@ -46,20 +49,22 @@ test_that("select on population", {
   s <- 0.1
   select_matrix[1, ] <- c(0.05, 1.0, 1 + 0.5 * s, 1 + s, 0)
 
-  selected_pop <- simulate_admixture(input_population = sourcepop,
+  selected_pop <- simulate_admixture(module =
+                                       ancestry_module(input_population = sourcepop,
+                                                       morgan = 1),
                                      select_matrix = select_matrix,
                                     pop_size = 100,
-                                    total_runtime = 100,
-                                    morgan = 1)
+                                    total_runtime = 100)
 
   testthat::expect_equal(length(selected_pop$population), 100)
   testthat::expect_true(verify_population(selected_pop$population))
 
-  selected_pop <- simulate_admixture(input_population = sourcepop,
+  selected_pop <- simulate_admixture(module =
+                                      ancestry_module(input_population = sourcepop,
+                                                       morgan = 1),
                                      select_matrix = select_matrix,
                                                pop_size = 100,
-                                               total_runtime = 100,
-                                               morgan = 1)
+                                               total_runtime = 100)
 
   testthat::expect_equal(length(selected_pop$population), 100)
   testthat::expect_true(verify_population(selected_pop$population))
@@ -74,36 +79,35 @@ test_that("select population two_alleles multiple markers", {
   select_matrix[1, ] <- c(0.25, 1.0, 1 + 0.5 * s, 1 + s, 0)
   select_matrix[2, ] <- c(0.75, 1.0, 1, 1 + s,  1)
 
-  selected_pop <- simulate_admixture(pop_size = 100,
-                                     number_of_founders = 10,
+  selected_pop <- simulate_admixture(module = ancestry_module(number_of_founders = 10),
+                                     pop_size = 100,
                                      total_runtime = 100,
-                                     morgan = 1,
                                      select_matrix = select_matrix)
 
   testthat::expect_equal(length(selected_pop$population), 100)
   testthat::expect_true(verify_population(selected_pop$population))
 
-  sourcepop <- simulate_admixture(pop_size = 100,
-                                  number_of_founders = 10,
-                                  total_runtime = 1000,
-                                  morgan = 1)
+  sourcepop <- simulate_admixture(module = ancestry_module(number_of_founders = 10),
+                                  pop_size = 100,
+                                  total_runtime = 1000)
 
   testthat::expect_true(verify_population(sourcepop))
 
-  selected_pop <- simulate_admixture(input_population = sourcepop,
+  selected_pop <- simulate_admixture(module =
+                                       ancestry_module(input_population = sourcepop),
                                      select_matrix = select_matrix,
                                      pop_size = 100,
-                                     total_runtime = 100,
-                                     morgan = 1)
+                                     total_runtime = 100)
 
   testthat::expect_equal(length(selected_pop$population), 100)
   testthat::expect_true(verify_population(selected_pop$population))
 
-  selected_pop <- simulate_admixture(input_population = sourcepop,
+  selected_pop <- simulate_admixture(module =
+                                       ancestry_module(input_population = sourcepop,
+                                                       morgan = 1),
                                      select_matrix = select_matrix,
                                      pop_size = 100,
-                                     total_runtime = 100,
-                                     morgan = 1)
+                                     total_runtime = 100)
 
   testthat::expect_equal(length(selected_pop$population), 100)
   testthat::expect_true(verify_population(selected_pop$population))
@@ -119,46 +123,30 @@ test_that("select population two_alleles regions", {
 
   markers <- seq(from = 0.2, to = 0.3, length.out = 21)
 
-  selected_pop <- simulate_admixture(pop_size = 100,
-                                     number_of_founders = 10,
+  selected_pop <- simulate_admixture(module = ancestry_module(number_of_founders = 10,
+                                                              markers = markers),
+    pop_size = 100,
                                      total_runtime = 100,
-                                     morgan = 1,
-                                     select_matrix = select_matrix,
-                                     markers = markers)
+                                     select_matrix = select_matrix)
 
   testthat::expect_equal(length(selected_pop$population), 100)
   testthat::expect_true(verify_population(selected_pop$population))
 
-  sourcepop <- simulate_admixture(pop_size = 100,
-                                 number_of_founders = 10,
-                                 total_runtime = 1000,
-                                 morgan = 1)
+  sourcepop <- simulate_admixture(module = ancestry_module(number_of_founders = 10),
+                                  pop_size = 100,
+                                  total_runtime = 1000)
 
   testthat::expect_true(verify_population(sourcepop))
 
-  selected_pop <- simulate_admixture(input_population = sourcepop,
+  selected_pop <- simulate_admixture(module = ancestry_module(input_population = sourcepop,
+                                                              markers = markers),
                                      select_matrix = select_matrix,
                                      pop_size = 100,
-                                     total_runtime = 100,
-                                     morgan = 1,
-                                     markers = markers)
+                                     total_runtime = 100)
 
   testthat::expect_equal(length(selected_pop$population), 100)
   testthat::expect_true(verify_population(selected_pop$population))
 
-  plot_joyplot_frequencies(selected_pop$frequencies,
-                      time_points = seq(from = 0,
-                                        to = 100,
-                                        by = 10)
-                      )
-
-  plot_joyplot_frequencies(selected_pop$frequencies,
-                      time_points = seq(from = 0,
-                                        to = 100,
-                                        by = 10),
-                      picked_ancestor = 1
-                     )
-
   plot_start_end(selected_pop)
   plot_start_end(selected_pop,
                  picked_ancestor = 0)
@@ -166,16 +154,13 @@ test_that("select population two_alleles regions", {
   plot_difference_frequencies(selected_pop)
   plot_difference_frequencies(selected_pop,
                               picked_ancestor = 0)
-
 })
 
 test_that("selection abuse", {
   testthat::skip_on_os("solaris")
   message("test selection abuse")
   sourcepop <- simulate_admixture(pop_size = 100,
-                                  number_of_founders = 2,
-                                  total_runtime = 100,
-                                  morgan = 1)
+                                  total_runtime = 100)
 
   testthat::expect_true(verify_population(sourcepop))
 
@@ -185,19 +170,17 @@ test_that("selection abuse", {
   select_matrix[2, ] <- c(0.15, 1.0, 1 + 0.5 * s, 1 + s, 0)
 
   testthat::expect_error(
-      simulate_admixture(input_population = sourcepop,
+      simulate_admixture(module = ancestry_module(input_population = sourcepop),
                          select_matrix = select_matrix,
-                        pop_size = 1000,
-                        total_runtime = 1000,
-                        morgan = 1),
+                         pop_size = 1000,
+                         total_runtime = 1000),
     "Can't start, there are NA values in the selection matrix!"
   )
 
   testthat::expect_error(
     simulate_admixture(select_matrix = select_matrix,
                        pop_size = 1000,
-                       total_runtime = 1000,
-                       morgan = 1),
+                       total_runtime = 1000),
     "Can't start, there are NA values in the selection matrix!"
   )
 
@@ -207,19 +190,17 @@ test_that("selection abuse", {
 
 
   testthat::expect_error(
-    simulate_admixture(input_population = sourcepop,
+    simulate_admixture(module = ancestry_module(input_population = sourcepop),
                        select_matrix = select_matrix,
                        pop_size = 1000,
-                       total_runtime = 1000,
-                       morgan = 1),
+                       total_runtime = 1000),
     "Can't start, there are NA values in the selection matrix!"
   )
 
   testthat::expect_error(
     simulate_admixture(select_matrix = select_matrix,
                        pop_size = 100,
-                       total_runtime = 10,
-                       morgan = 1),
+                       total_runtime = 10),
     "Can't start, there are NA values in the selection matrix!"
   )
 
@@ -234,19 +215,17 @@ test_that("selection abuse", {
   select_matrix[1, ] <- c(0.5, 0.1, 0.2)
 
   testthat::expect_error(
-    simulate_admixture(input_population = sourcepop,
+    simulate_admixture(module = ancestry_module(input_population = sourcepop),
                        select_matrix = select_matrix,
                        pop_size = 1000,
-                       total_runtime = 1000,
-                       morgan = 1)
+                       total_runtime = 10)
   )
 
   testthat::expect_error(
-    simulate_admixture(input_population = sourcepop,
+    simulate_admixture(module = ancestry_module(input_population = sourcepop,
+                                                number_of_founders = 10),
                        select_matrix = select_matrix,
                        pop_size = 100,
-                       number_of_founders = 10,
-                       total_runtime = 10,
-                       morgan = 1)
+                       total_runtime = 10)
   )
 })
